@@ -1,11 +1,5 @@
 package Net::Works::Types;
-{
-  $Net::Works::Types::VERSION = '0.16';
-}
-BEGIN {
-  $Net::Works::Types::AUTHORITY = 'cpan:DROLSKY';
-}
-
+$Net::Works::Types::VERSION = '0.17';
 use strict;
 use warnings;
 
@@ -18,7 +12,7 @@ our @EXPORT_OK = qw(
     Int
     IPInt
     IPVersion
-    MaskLength
+    PrefixLength
     NetWorksAddress
     PackedBinary
     Str
@@ -27,7 +21,7 @@ our @EXPORT_OK = qw(
 {
     my $t = quote_sub(
         q{
-( defined $_[0] && !ref $_[0] && $_[0] =~ /^[0-9]+$/ )
+( defined $_[0] && !ref $_[0] && $_[0] =~ /^[0-9]+\z/ )
     or Net::Works::Types::_confess(
     '%s is not a valid integer for an IP address',
     $_[0]
@@ -42,7 +36,7 @@ our @EXPORT_OK = qw(
     my $t = quote_sub(
         q{
 (
-    defined $_[0] && ( ( !ref $_[0] && $_[0] =~ /^[0-9]+$/ )
+    defined $_[0] && ( ( !ref $_[0] && $_[0] =~ /^[0-9]+\z/ )
         || ( Scalar::Util::blessed( $_[0] ) && $_[0]->isa('Math::UInt128') ) )
     )
     or Net::Works::Types::_confess(
@@ -72,13 +66,13 @@ our @EXPORT_OK = qw(
 {
     my $t = quote_sub(
         q{
-( !ref $_[0] && $_[0] >= 0 && $_[0] <= 128 )
+( !ref $_[0] && $_[0] =~ /^[0-9]+\z/ && $_[0] <= 128 )
     or Net::Works::Types::_confess(
-    '%s is not a valid IP network mask length (0-128)', $_[0] );
+    '%s is not a valid IP network prefix length (0-128)', $_[0] );
 }
     );
 
-    sub MaskLength () { $t }
+    sub PrefixLength () { $t }
 }
 
 {
